==> tecfy_core_package-1.0.23.tar.gz: lib/services/timeout_message.dart <==
part of tecfy_core_client_package;

class TimeoutMessage {
  static int currentMessageId = 0;
  static OverlayEntry? _activeOverlay;
  static Future<dynamic> Function()? beforeClose;

  static Future hide() async {
    if (_activeOverlay == null) {
      return;
    }

    if (beforeClose != null) {
      await beforeClose?.call();
      _activeOverlay?.remove();
      _activeOverlay = null;
      await Future.delayed(Duration(milliseconds: 500));
      return;
    }
    try {
      _activeOverlay?.remove();
    } catch (err) {
      print('XXXXXXXXXXXX cannot remove old overlay $err');
    }
    _activeOverlay = null;
  }

  static Future show(String title,
      {String? message,
      double top = 80,
      double left = 20,
      double width = 200,
      bool showSilent = false,
      int timeoutMiniseconds = 3000,
      onClick}) async {
    if (!showSilent) {
      SoundService.play();
    }
    await hide();

    int local = ++currentMessageId; // track the messages

    _activeOverlay = OverlayEntry(
        builder: (BuildContext context) => TimeoutMessageDialog(title,
            message: message,
            top: top,
            width: width,
            left: left,
            //parentContext: context,
            onCLick: onClick));

    if (TecfyCoreApp.appGlobalkey.currentState?.overlay != null) {
      TecfyCoreApp.appGlobalkey.currentState?.overlay?.insert(_activeOverlay!);
    } else {
      print(
          'TimeoutMessage Error XXXXXXXXXXXXXXXXXXXXXXXXX context doesn\'t have overlat XXXXXXXXXXXXX');
      return;
    }
    // if (Overlay.of(context) != null && Overlay.of(context).mounted) {
    //   Overlay.of(context).insert(_activeOverlay);
    // } else {
    //   print(
    //       'TimeoutMessage Error XXXXXXXXXXXXXXXXXXXXXXXXX context doesn\'t have overlat XXXXXXXXXXXXX');
    //   return;
    // }

    //if (timeoutMiniseconds != null) {
    Future.delayed(Duration(milliseconds: timeoutMiniseconds)).then((_) {
      // make sure that you're removing the current message
      if (local == currentMessageId) {
        hide();
      }
    });
    //}
  }
}

class TimeoutMessageDialog extends StatefulWidget {
  final String title;
  final String? message;
  final BuildContext? parentContext;
  final double? left;
  final double? top;
  final double? width;
  final onCLick;
  TimeoutMessageDialog(this.title,
      {this.message,
      this.parentContext,
      this.top,
      this.width,
      this.left,
      this.onCLick});
  @override
  _TimeoutMessageDialogState createState() => _TimeoutMessageDialogState();
}

class _TimeoutMessageDialogState extends State<TimeoutMessageDialog>
    with SingleTickerProviderStateMixin {
  AnimationController? controller;
  Animation<double>? _angleAnimation;
  Animation<double>? _feedAnimation;
  Animation<double>? closeAnimation;

  double? left;
  double? top;
  double? width;

  bool isArabic = false;

  @override
  void initState() {
    isArabic = LocalConfigService.isArabic;

    TimeoutMessage.beforeClose = () async {
      await controller?.animateBack(0);
    };

    super.initState();

    controller =
        AnimationController(vsync: this, duration: Duration(milliseconds: 600));
    _angleAnimation = Tween<double>(begin: 90, end: 0).animate(CurvedAnimation(
        parent: controller!, curve: Curves.elasticOut)); //Curves.elasticOut

    _feedAnimation = Tween<double>(begin: 0.0, end: 1)
        .animate(CurvedAnimation(parent: controller!, curve: Curves.easeIn));

    controller!.addListener(() {
      setState(() {});
    });

    controller!.forward();
  }

  @override
  Widget build(BuildContext context) {
    if (widget.parentContext != null) {
      RenderBox? renderBox =
          widget.parentContext!.findRenderObject() as RenderBox;
      var size = renderBox.size;
      var offset = renderBox.localToGlobal(Offset.zero);
      top = widget.top ?? offset.dy + size.height + 5.0;
      left = widget.left ?? offset.dx;
      width = widget.width ?? size.width;
    }
    return Positioned(
      right: isArabic ? null : (left ?? widget.left),
      left: isArabic ? left ?? widget.left : null,
      top: top ?? widget.top,
      width: width ?? widget.width,
      child: Transform.rotate(
        alignment: isArabic ? Alignment.topLeft : Alignment.topRight,
        angle: (_angleAnimation!.value * 3.14159 / 180),
        child: Opacity(
          opacity: _feedAnimation!.value,
          child: MaterialButton(
              padding: EdgeInsets.all(10),
              shape: RoundedRectangleBorder(
                  borderRadius: BorderRadius.only(
                      topLeft:
                          isArabic ? Radius.circular(25) : Radius.circular(0),
                      topRight:
                          isArabic ? Radius.circular(0) : Radius.circular(25))),
              color: ThemeService.mainColor,
              elevation: 10.0,
              child: Column(
                mainAxisAlignment: MainAxisAlignment.start,
                crossAxisAlignment: CrossAxisAlignment.stretch,
                children: <Widget>[
                  Text(widget.title,
                      style: TextStyle(
                          fontWeight: FontWeight.bold,
                          color: ThemeService.textOnMainColor)),
                  widget.message == null
                      ? Container()
                      : Text(widget.message!,
                          style: TextStyle(
                              fontWeight: FontWeight.normal,
                              color: ThemeService.textOnMainColor))
                ],
              ),
              onPressed: () {
                TimeoutMessage.hide();
                if (widget.onCLick != null) {
                  widget.onCLick();
                }
              }),
        ),
      ),
    );
  }

  divider() {
    return Padding(
        padding: EdgeInsets.symmetric(vertical: 10),
        child: Container(height: 1, color: Colors.white));
  }
}

==> tecfy_core_package-1.2.7.tar.gz: lib/services/timeout_message.dart <==
part of tecfy_core_client_package;

class TimeoutMessage {
  static int currentMessageId = 0;
  static OverlayEntry? _activeOverlay;
  static Future<dynamic> Function()? beforeClose;

  static Future hide() async {
    if (_activeOverlay == null) {
      return;
    }

    if (beforeClose != null) {
      await beforeClose?.call();
      _activeOverlay?.remove();
      _activeOverlay = null;
      await Future.delayed(Duration(milliseconds: 500));
      return;
    }
    try {
      _activeOverlay?.remove();
    } catch (err) {
      print('XXXXXXXXXXXX cannot remove old overlay $err');
    }
    _activeOverlay = null;
  }

  static Future show(String title,
      {String? message,
      double top = 80,
      double left = 20,
      double width = 200,
      bool showSilent = false,
      int timeoutMiniseconds = 3000,
      onClick}) async {
    if (!showSilent) {
      SoundService.play();
    }
    await hide();

    int local = ++currentMessageId; // track the messages

    _activeOverlay = OverlayEntry(
        builder: (BuildContext context) => TimeoutMessageDialog(title,
            message: message,
            top: top,
            width: width,
            left: left,
            //parentContext: context,
            onCLick: onClick));

    if (TecfyBasicApp.appGlobalkey.currentState?.overlay != null) {
      TecfyBasicApp.appGlobalkey.currentState?.overlay?.insert(_activeOverlay!);
    } else {
      print(
          'TimeoutMessage Error XXXXXXXXXXXXXXXXXXXXXXXXX context doesn\'t have overlat XXXXXXXXXXXXX');
      return;
    }
    // if (Overlay.of(context) != null && Overlay.of(context).mounted) {
    //   Overlay.of(context).insert(_activeOverlay);
    // } else {
    //   print(
    //       'TimeoutMessage Error XXXXXXXXXXXXXXXXXXXXXXXXX context doesn\'t have overlat XXXXXXXXXXXXX');
    //   return;
    // }

    //if (timeoutMiniseconds != null) {
    Future.delayed(Duration(milliseconds: timeoutMiniseconds)).then((_) {
      // make sure that you're removing the current message
      if (local == currentMessageId) {
        hide();
      }
    });
    //}
  }
}

class TimeoutMessageDialog extends StatefulWidget {
  final String title;
  final String? message;
  final BuildContext? parentContext;
  final double? left;
  final double? top;
  final double? width;
  final onCLick;
  TimeoutMessageDialog(this.title,
      {this.message,
      this.parentContext,
      this.top,
      this.width,
      this.left,
      this.onCLick});
  @override
  _TimeoutMessageDialogState createState() => _TimeoutMessageDialogState();
}

class _TimeoutMessageDialogState extends State<TimeoutMessageDialog>
    with SingleTickerProviderStateMixin {
  AnimationController? controller;
  Animation<double>? _angleAnimation;
  Animation<double>? _feedAnimation;
  Animation<double>? closeAnimation;

  double? left;
  double? top;
  double? width;

  bool isArabic = false;

  @override
  void initState() {
    isArabic = LocalConfigService.isArabic;

    TimeoutMessage.beforeClose = () async {
      await controller?.animateBack(0);
    };

    super.initState();

    controller =
        AnimationController(vsync: this, duration: Duration(milliseconds: 600));
    _angleAnimation = Tween<double>(begin: 90, end: 0).animate(CurvedAnimation(
        parent: controller!, curve: Curves.elasticOut)); //Curves.elasticOut

    _feedAnimation = Tween<double>(begin: 0.0, end: 1)
        .animate(CurvedAnimation(parent: controller!, curve: Curves.easeIn));

    controller!.addListener(() {
      setState(() {});
    });

    controller!.forward();
  }

  @override
  Widget build(BuildContext context) {
    if (widget.parentContext != null) {
      RenderBox? renderBox =
          widget.parentContext!.findRenderObject() as RenderBox;
      var size = renderBox.size;
      var offset = renderBox.localToGlobal(Offset.zero);
      top = widget.top ?? offset.dy + size.height + 5.0;
      left = widget.left ?? offset.dx;
      width = widget.width ?? size.width;
    }
    return Positioned(
      right: isArabic ? null : (left ?? widget.left),
      left: isArabic ? left ?? widget.left : null,
      top: top ?? widget.top,
      width: width ?? widget.width,
      child: Transform.rotate(
        alignment: isArabic ? Alignment.topLeft : Alignment.topRight,
        angle: (_angleAnimation!.value * 3.14159 / 180),
        child: Opacity(
          opacity: _feedAnimation!.value,
          child: MaterialButton(
              padding: EdgeInsets.all(10),
              shape: RoundedRectangleBorder(
                  borderRadius: BorderRadius.only(
                      topLeft:
                          isArabic ? Radius.circular(25) : Radius.circular(0),
                      topRight:
                          isArabic ? Radius.circular(0) : Radius.circular(25))),
              color: ThemeService.mainColor,
              elevation: 10.0,
              child: Column(
                mainAxisAlignment: MainAxisAlignment.start,
                crossAxisAlignment: CrossAxisAlignment.stretch,
                children: <Widget>[
                  Text(widget.title,
                      style: TextStyle(
                          fontWeight: FontWeight.bold,
                          color: ThemeService.textOnMainColor)),
                  widget.message == null
                      ? Container()
                      : Text(widget.message!,
                          style: TextStyle(
                              fontWeight: FontWeight.normal,
                              color: ThemeService.textOnMainColor))
                ],
              ),
              onPressed: () {
                TimeoutMessage.hide();
                if (widget.onCLick != null) {
                  widget.onCLick();
                }
              }),
        ),
      ),
    );
  }

  divider() {
    return Padding(
        padding: EdgeInsets.symmetric(vertical: 10),
        child: Container(height: 1, color: Colors.white));
  }
}
